==> haskell-persistent-sqlite-2.6.2-32-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-sqlite
version: 2.6.2
id: persistent-sqlite-2.6.2-8Wjn2oEHOLMQ1ikCedeoz
key: persistent-sqlite-2.6.2-8Wjn2oEHOLMQ1ikCedeoz
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Sqlite Database.Persist.Sqlite
abi: 171add8dc1790015e96bd7d741a481e1
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-sqlite-2.6.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-sqlite-2.6.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/persistent-sqlite-2.6.2
hs-libraries: HSpersistent-sqlite-2.6.2-8Wjn2oEHOLMQ1ikCedeoz
extra-libraries:
    pthread
depends:
    aeson-1.1.2.0-6MVvUcgiXyL5LInpwFqRIH base-4.9.0.0
    bytestring-0.10.8.1 conduit-1.2.10-HIC8vE5Ia4HDIPETJJNHDv
    containers-0.5.7.1 microlens-th-0.4.1.1-EyW2sEkIfU1AMu1ncaPfsL
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.24-7gRQSYJ9o62K37akkpEQgF
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    persistent-2.6.1-Bms8UcNe7SU94p1UOqGWGn
    resource-pool-0.2.3.2-21N7ezGHoldXZQkL6dM1P
    resourcet-1.1.9-4wjmwiYhI4Y4ny0clYPjM8
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v time-1.6.0.1
    transformers-0.5.2.0
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
haddock-interfaces: /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock
haddock-html: /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-sqlite-2.6.2-34-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-sqlite
version: 2.6.2
id: persistent-sqlite-2.6.2-BdDn9SNcHNv67VOoVxtLal
key: persistent-sqlite-2.6.2-BdDn9SNcHNv67VOoVxtLal
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Sqlite Database.Persist.Sqlite
abi: 0b5d12e98068011b698a8ee61d7faf2b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-sqlite-2.6.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-sqlite-2.6.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/persistent-sqlite-2.6.2
hs-libraries: HSpersistent-sqlite-2.6.2-BdDn9SNcHNv67VOoVxtLal
extra-libraries:
    pthread
depends:
    aeson-1.1.2.0-6MVvUcgiXyL5LInpwFqRIH base-4.9.0.0
    bytestring-0.10.8.1 conduit-1.2.11-5u7YE5Ecuce5vjjIFEkula
    containers-0.5.7.1 microlens-th-0.4.1.1-EyW2sEkIfU1AMu1ncaPfsL
    monad-control-1.0.2.0-4qPEnRApnc4gRDkIzJcM5
    monad-logger-0.3.24-Kten253AOusLQkAtskwVZp
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    persistent-2.6.1-CnT2JRqLuTu3pwF7U7MLrf
    resource-pool-0.2.3.2-IvrPp1JcX2T6Ac9cWpKKrl
    resourcet-1.1.9-5Fmv0DqXfJBCCiUazI0vW3
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v time-1.6.0.1
    transformers-0.5.2.0
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
haddock-interfaces: /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock
haddock-html: /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
